@@ -55,11 +55,6 @@ class CachingResolver(lxml.etree.Resolver):
                  templates_path=base.default_options.template_dir, verbose=None, quiet=None,
                  no_network=None, network_locs= [
                      'https://bib.ietf.org/public/rfc/',
-                     'https://xml2rfc.ietf.org/public/rfc/',
-                     'https://xml2rfc.tools.ietf.org/public/rfc/',
-                     'http://bib.ietf.org/public/rfc/',
-                     'http://xml2rfc.ietf.org/public/rfc/',
-                     'http://xml2rfc.tools.ietf.org/public/rfc/',
                  ],
                  rfc_number=None, options=base.default_options):
         self.quiet = quiet if quiet != None else options.quiet
@@ -105,7 +100,7 @@ class CachingResolver(lxml.etree.Resolver):
                     # Can't write to this directory, try the next one
                     pass
         if not self.write_cache:
-            xml2rfc.log.warn('Unable to find a suitible cache directory to '
+            xml2rfc.log.warn('Unable to find a suitable cache directory to '
                             'write to, trying the following directories:\n ',
                             '\n  '.join(self.read_caches),
                             '\nTry giving a specific directory with --cache.')
@@ -184,7 +179,7 @@ class CachingResolver(lxml.etree.Resolver):
                   Try each directory in LOCAL_LIB_DIRS + REQUEST, otherwise
                   Try NETWORK + REQUEST
                 Else (REQUEST is simply a filename)
-                  [Recursively] Try each directory in LOCAL_LIB_DIRS + REQUEST, otherise
+                  [Recursively] Try each directory in LOCAL_LIB_DIRS + REQUEST, otherwise
                   Try each explicit (bibxml, bibxml2...) subdirectory in NETWORK + REQUEST
 
             Finally if the path returned is a network URL, use the cached
@@ -197,9 +192,7 @@ class CachingResolver(lxml.etree.Resolver):
               on the CLI this is set by $XML_LIBRARY, defaulting to 
               ['/usr/share/xml2rfc'].  On the GUI this can be configured
               manually but has the same initial defaults.
-            - NETWORK refers to the online citation library.  On the CLI this
-              is http://xml2rfc.ietf.org/public/rfc/.  On the GUI this 
-              can be configured manually but has the same initial default.
+            - NETWORK refers to the online citation library.
 
             The caches in read_dirs are consulted in sequence order to find the
             request.  If not found, the request will be cached at write_dir.
@@ -234,12 +227,10 @@ class CachingResolver(lxml.etree.Resolver):
                     result = os.path.join(self.source_dir, basename)
                     attempts.append(result)
         else:
-            if self.options and self.options.vocabulary == 'v3':
-                paths = [ request ]
-            elif not request.endswith('.xml'):
-                paths = [ request, request + '.xml' ]
+            if not request.endswith('.xml'):
+                paths = [ request + '.xml', request ]
             else:
-                paths = [ request ]                
+                paths = [ request ]
             if os.path.isabs(paths[0]):
                 # Absolute path, return as-is
                 for path in paths:
@@ -351,7 +342,7 @@ class CachingResolver(lxml.etree.Resolver):
             raise error
         else:
             if not tried_cache:
-                # Haven't printed a verbose messsage yet
+                # Haven't printed a verbose message yet
                 typename = self.include and 'include' or 'entity'
                 xml2rfc.log.note('Resolving ' + typename + '...', result)
             return result
@@ -480,10 +471,7 @@ class XmlRfcParser:
     def __init__(self, source, verbose=None, quiet=None, options=base.default_options,
                  cache_path=None, templates_path=base.default_options.template_dir, library_dirs=None, add_xmlns=False,
                  no_network=None, network_locs=[
-                     'https://xml2rfc.ietf.org/public/rfc/',
-                     'https://xml2rfc.tools.ietf.org/public/rfc/',
-                     'http://xml2rfc.ietf.org/public/rfc/',
-                     'http://xml2rfc.tools.ietf.org/public/rfc/',
+                     'https://bib.ietf.org/public/rfc/',
                  ]
                  ):
         self.options = options
@@ -655,6 +643,8 @@ class XmlRfcParser:
                 pis = xmlrfc.pis.copy() 
                 if 'include' in pidict and pidict['include']:
                     request = pidict['include']
+                    if xmlrfc.getroot().get('version', '3') in ['3', ]:
+                        xml2rfc.log.warn(f'XInclude should be used instead of PI include for {request}')
                     path = self.cachingResolver.getReferenceRequest(request,
                            # Pass the line number in XML for error bubbling
                            include=True, line_no=getattr(element, 'sourceline', 0))
