@@ -25,11 +25,9 @@ except ImportError:
     pass
 
 from xml2rfc import strings, log
-from xml2rfc.uniscripts import is_script
 from xml2rfc.util.date import extract_date, augment_date, format_date, get_expiry_date
 from xml2rfc.util.name import short_author_ascii_name_parts, full_author_name_expansion, short_author_name_parts
-from xml2rfc.util.unicode import ( punctuation, unicode_replacements, unicode_content_tags, bare_unicode_tags,
-    bare_latin_tags, unicode_attributes, downcode, downcode_punctuation, is_svg)
+from xml2rfc.util.unicode import is_svg
 from xml2rfc.utils import namespaces, find_duplicate_ids, slugify
 
 
@@ -119,6 +117,7 @@ default_options.__dict__ = {
         'v3': True,
         'vocabulary': 'v2',
         'widows': 2,
+        'warn_bare_unicode': False,
     }
 
 class _RfcItem:
@@ -2035,61 +2034,6 @@ class BaseV3Writer(object):
             text = 'Expires %s' % format_date(*parts, legacy=self.options.legacy_date_format)
         return text
 
-    def downcode_punctuation(self):
-        self.downcode(replacements=punctuation)
-        self.downcode_reference_punctuation()
-
-    def downcode(self, replacements=unicode_replacements):
-        """
-
-        Traverses an lxml.etree and replaces unicode characters with the proper
-        equivalents specified in rfc2629-xhtml.ent, resulting in no non-ascii
-        characters except in elements that explicitly permit non-ascii content.
-
-        """
-        for e in self.tree.iter():
-            if is_svg(e):
-                continue
-            if e.text:
-                if not e.tag in unicode_content_tags:
-                    try:
-                        e.text.encode('ascii')
-                    except UnicodeEncodeError:
-                        e.text = downcode(e.text, replacements=replacements)
-                elif e.tag in bare_unicode_tags:
-                    pass
-                elif e.tag in bare_latin_tags and is_script(e.text, 'Latin'):
-                    pass
-                elif not e.get('ascii'):
-                    try:
-                        e.text.encode('ascii')
-                    except UnicodeEncodeError:
-                        e.text = downcode(e.text, replacements=replacements)
-            if e.tail:
-                if not e.getparent().tag in unicode_content_tags:
-                    try:
-                        e.tail.encode('ascii')
-                    except UnicodeEncodeError:
-                        e.tail = downcode(e.tail, replacements=replacements)
-
-    def downcode_attributes(self, replacements=unicode_replacements):
-        for e in self.tree.iter():
-            for key in e.attrib.keys():
-                if not (e.tag, key) in unicode_attributes:
-                    try:
-                        e.get(key).encode('ascii')
-                    except UnicodeEncodeError:
-                        e.set(key, downcode(e.get(key), replacements=replacements))
-
-    def downcode_reference_punctuation(self):
-        for r in self.tree.xpath('.//references'):
-            for e in r.iter():
-                for key in e.attrib.keys():
-                    try:
-                        e.get(key).encode('ascii')
-                    except UnicodeEncodeError:
-                        e.set(key, downcode_punctuation(e.get(key)))
-
     def pretty_print_prep(self, e, p):
         ind = self.options.indent
         ## The actual printing is done in self.write()
@@ -2172,7 +2116,9 @@ class BaseV3Writer(object):
             self.warn(e, 'Duplicate xsd:ID attribute %s="%s" found.  This will cause validation failure.' % (attr, id, ))
 
         try:
-            self.v3_rng.assertValid(self.tree)
+            # Use a deepcopy to avoid any memory issues.
+            tree = copy.deepcopy(self.tree)
+            self.v3_rng.assertValid(tree)
             return True
         except Exception as e:
             lxmlver = lxml.etree.LXML_VERSION[:3]
@@ -2221,13 +2167,9 @@ class BaseV3Writer(object):
         # schema, there is no dependency in the underlying schema on the root
         # element attributes.  In order to avoid very long validation times, we
         # strip the root attributes before validation, and put them back
-        # afterwards.  
-        for k in e.keys():
-            if not e.get(k):
-                del e.attrib[k]
-        attrib = copy.deepcopy(e.attrib) 
-        for k in attrib.keys():
-            del e.attrib[k]
+        # afterwards.
+        attrib = copy.deepcopy(e.attrib)
+        e.attrib.clear()
         #
         if not self.validate('after', warn=True):
             self.note(None, "Schema validation failed for input document")
@@ -2236,8 +2178,7 @@ class BaseV3Writer(object):
         #
         keys = list(attrib.keys())
         keys.sort()
-        for k in keys:
-            e.set(k, attrib[k])
+        e.attrib.update(attrib)
 
     def remove(self, p, e):
         # Element.remove(child) removes both the child and its tail, so in
